@@ -2,6 +2,7 @@ use crate::scenario::Scenario;
 use crossbeam_channel::Receiver;
 
 pub mod fuzzy_request_generator;
+pub mod hyper;
 pub mod reqwest_generator;
 
 /// Traffic Generators are the bread and butter of pdc.
@@ -15,6 +16,10 @@ pub trait TrafficGenerator<T: Scenario>: Send + Sync {
     fn get_data_rate_channel(&self) -> Receiver<(f32, f32)>;
     /// Give a bounded channel that sends the total amount of packets/requests sent
     fn get_sent_packets_channel(&self) -> Receiver<usize>;
+    /// Give a bounded channel that sends time series data on the send rate of
+    /// a generator. The data is encoded as
+    /// `(Miliseconds since start of scenario, counts/sec)`.
+    fn get_error_rate_channel(&self) -> Receiver<(f32, f32)>;
     /// Send a single packet per call, used for debuging and low traffic testing.
     fn send_packet(&mut self);
     /// Sets a [`Scenario`] for the generator to try and replicate.
@@ -26,3 +31,11 @@ pub trait TrafficGenerator<T: Scenario>: Send + Sync {
     /// Run the generator at full throttle!
     fn fire_hose(&mut self);
 }
+
+#[derive(Clone, Debug)]
+pub struct HttpConfig {
+    pub url: String,
+    /// HTTP Method, Defaults to GET.
+    pub method: String,
+    pub body: String,
+}
